@@ -567,16 +567,16 @@ class TestCounter(TestCase):
         self.assertEqual(formatted, bartext)
 
         ctr.bar_format = u'{count_0} {percentage_0} | {count_1} {percentage_1} {rate_1} {eta_1}' + \
-                         u' | {count_2} {percentage_2}'
+                         u' | {count_2} {percentage_2} | {count_00} {percentage_00:.1f}'
 
         formatted = ctr.format(elapsed=5, width=80)
-        self.assertEqual(formatted, u'35 35.0 | 5 5.0 1.0 01:35 | 10 10.0')
+        self.assertEqual(formatted, u'35 35.0 | 5 5.0 1.0 01:35 | 10 10.0 | 15 15.0')
 
     def test_subcounter_count_gt_total(self):
         """
         When total is exceeded, subcounter fields are still populated
         """
-        counter_format = u'{count_0} | {count_1} {rate_1} | {count_2}'
+        counter_format = u'{count_0} | {count_1} {rate_1} | {count_2} | {count_00}'
         ctr = Counter(stream=self.tty.stdout, total=100, counter_format=counter_format)
 
         ctr.count = 500
@@ -584,7 +584,23 @@ class TestCounter(TestCase):
         subcounter1.count = 50
         ctr.add_subcounter('blue', count=100)
         formatted = ctr.format(elapsed=50, width=80)
-        self.assertEqual(formatted, u'350 | 50 1.0 | 100')
+        self.assertEqual(formatted, u'350 | 50 1.0 | 100 | 150')
+
+    def test_subcounter_count_0(self):
+        """
+        When all of count is covered by subcounters, nothing should print for main counter
+        """
+
+        ctr = Counter(stream=self.tty.stdout, total=100, bar_format=u'{bar}')
+        term = ctr.manager.term
+        ctr.count = 50
+        ctr.add_subcounter('yellow', count=44)
+        ctr.add_subcounter('blue', count=4)
+        ctr.add_subcounter('red', count=2)
+
+        formatted = ctr.format(width=80)
+        bartext = term.red(BLOCK*2) + term.blue(BLOCK*3) + term.yellow(BLOCK*35) + ' ' * 40
+        self.assertEqual(formatted, bartext)
 
     def test_close(self):
         manager = MockManager()
